from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class FruitBase(BaseModel):
    name: str = Field(..., description="Name of the fruit")
    description: Optional[str] = Field(None, description="Description of the fruit")

class FruitCreate(FruitBase):
    pass

class FruitUpdate(BaseModel):
    name: Optional[str] = Field(None, description="Name of the fruit")
    description: Optional[str] = Field(None, description="Description of the fruit")

class FruitSchema(FruitBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        from_attributes = True
        schema_extra = {
            "example": {
                "id": "f47ac10b-58cc-4372-a567-0e02b2c3d479",
                "name": "Apple",
                "description": "A sweet and crunchy fruit",
                "created_at": "2023-01-01T12:00:00",
                "updated_at": "2023-01-01T12:00:00"
            }
        }